@@ -1,10 +1,15 @@
-from typing import List
+from typing import (
+    List,
+    Optional,
+)
 
 from pydantic import BaseModel
 
 
 class AuthenticatorData(BaseModel):
     shared_secret: str
+    identity_secret: str
+    device_id: str
 
 
 class Params(BaseModel):
@@ -45,4 +50,4 @@ class SteamAuthorizationStatus(BaseModel):
     steamid: str
     accountid: int
     account_name: str
-    token: str
+    token: Optional[str]
