@@ -1,19 +1,22 @@
-from typing import Dict
+from typing import (
+    Dict,
+    Optional,
+    Type,
+)
 
 from .codes import STEAM_ERROR_CODES
 
 
-_CUSTOM_ERROR_EXCEPTIONS = {}
-
-
 class SteamError(Exception):
 
-    def __init__(self, error_code: int):
+    def __init__(self, error_code: int, error_msg: Optional[str] = None):
         self.error_code = error_code
+        self.error_msg = error_msg
 
     def __str__(self) -> str:
         return str({
             'error': STEAM_ERROR_CODES.get(self.error_code, self.error_code),
+            'msg': self.error_msg,
             'code': self.error_code,
         })
 
@@ -22,7 +25,10 @@ class UnknownSteamError(SteamError):
     ...
 
 
-def custom_error_exception(errors: Dict) -> None:
+_CUSTOM_ERROR_EXCEPTIONS: Dict[int, Type[SteamError]] = {}
+
+
+def custom_error_exception(errors: Dict[int, Type[SteamError]]) -> None:
     global _CUSTOM_ERROR_EXCEPTIONS
     if not isinstance(errors, dict):
         raise TypeError('The error argument should be dict')
@@ -35,3 +41,11 @@ def custom_error_exception(errors: Dict) -> None:
         if _error not in STEAM_ERROR_CODES:
             raise TypeError(f'Unknown error code {_error}')
         _CUSTOM_ERROR_EXCEPTIONS[_error] = _exception
+
+
+class UnauthorizedSteamRequestError(Exception):
+    ...
+
+
+class TooManySteamRequestsError(Exception):
+    ...
